/*
  Benoît Langeraert
  
  Code for the Arduino Nano 33 BLE that reads EMG-data, this code works as central in the BLE-communication.

  Scanning until following UUID is found: "19b10000-e8f2-537e-4f6c-d104768a1214".
  Then a connection will be established that will send EMG-data through BLE to the Maix Bit shield.
  The EMG-data will be read with an MyoWare sensor on the Analog port '0'.

  This code is based on Arduino example code is in the public domain.
*/

#include <ArduinoBLE.h>

void setup() {
  Serial.begin(9600);

  // initialize the BLE hardware
  BLE.begin();

  Serial.println("Arduino Nano 33 BLE: Read EMG-data and send to the Maix Bit shield");

  // start scanning for peripherals
  BLE.scanForUuid("19b10000-e8f2-537e-4f6c-d104768a1214");
}

void loop() {
  // check if a peripheral has been discovered
  BLEDevice peripheral = BLE.available();

  if (peripheral) {
    // discovered a peripheral, print out address, local name, and advertised service
    Serial.print("Found ");
    Serial.print(peripheral.address());
    Serial.print(" '");
    Serial.print(peripheral.localName());
    Serial.print("' ");
    Serial.print(peripheral.advertisedServiceUuid());
    Serial.println();

    if (peripheral.localName() != "Maix Bit shield") {
      return;
    }

    // stop scanning
    BLE.stopScan();

    controlLed(peripheral);

    // peripheral disconnected, start scanning again
    BLE.scanForUuid("19b10000-e8f2-537e-4f6c-d104768a1214");
  }
}

void controlLed(BLEDevice peripheral) {
  // connect to the peripheral
  Serial.println("Connecting ...");

  if (peripheral.connect()) {
    Serial.println("Connected");
  } else {
    Serial.println("Failed to connect!");
    return;
  }

  // discover peripheral attributes
  Serial.println("Discovering attributes ...");
  if (peripheral.discoverAttributes()) {
    Serial.println("Attributes discovered");
  } else {
    Serial.println("Attribute discovery failed!");
    peripheral.disconnect();
    return;
  }

  // retrieve the LED characteristic
  BLECharacteristic ledCharacteristic = peripheral.characteristic("19b10000-e8f2-537e-4f6c-d104768a1214");

  while (peripheral.connected()) {

    int sensorValue = analogRead(A0); // read in muscle data
    if (sensorValue < 300){
      ledCharacteristic.writeValue((byte)0x01);
      delay(100);
    } else if (sensorValue > 300){ // else would be fine too, this is just to show that a vale above 300 would return another value
      ledCharacteristic.writeValue((byte)0x00);
      delay(100);
    }
    Serial.println(sensorValue);
  }

  Serial.println("Peripheral disconnected");
}
