 # Benoît Langeraert
 # This code is for the Maix Bit with the Maix Bit shield atttached to it.
 # It will receive 2 different kind of values through I2C depending on the EMG-data measured.
 # Depending on the value the Hussein arm will close or open it's hand.
 # A demo video is available on: https://doi.org/10.4121/21803991.v1 called
 # "excitatie_spier_tot_beweging_prothese.mp4".
 # Servo motors are attached to GPIO pins: 1, 2, 3 and 4.
 # Chosen I2C pins are 34 (SCL) and 33 (SDA)
 # The thumb will not be actuated in this code, the rest of the fingers will be.

from machine import Timer, PWM
from machine import I2C
import time
from board import board_info

tim1 = Timer ( Timer . TIMER0 , Timer . CHANNEL0 , mode = Timer . MODE_PWM )
tim2 = Timer ( Timer . TIMER0 , Timer . CHANNEL1 , mode = Timer . MODE_PWM )
tim3 = Timer ( Timer . TIMER0 , Timer . CHANNEL2 , mode = Timer . MODE_PWM )
tim4 = Timer ( Timer . TIMER0 , Timer . CHANNEL3 , mode = Timer . MODE_PWM )

print("Board info: ", board_info)

# Class to help actuate the servo motors through a given angle.
def Servo (servo, angle):
    servo.duty(((angle*9.45)/180)+2.95)
    time.sleep(0.05)

pink_ring = PWM(tim1, freq=50, duty=3, pin=0)
wijs = PWM(tim2, freq=50, duty=3, pin=1)
pols = PWM(tim3, freq=50, duty=3, pin=2)
middel = PWM(tim4, freq=50, duty=3, pin=3)


# These values were chosen as these proved to be the best values for my made Hussein arm.
# These values depend on the tension of the cords,
# the range of the fingers and how the horn was placed on the servo motor (depending on the current
# rotation of the servo motor).
def open_hand():
    Servo(pols,170)
    Servo(pink_ring,20)
    Servo(wijs, 130)
    Servo(middel, 10)

def close_hand():
    Servo(pols,90)
    Servo(pink_ring,120)
    Servo(wijs, 0)
    Servo(middel, 170)


i2c = I2C(I2C.I2C0, freq=100000, scl=34, sda=33) # Setting up the I2C communication on pin 34 and 33

devices = i2c.scan()

print("devices: ", devices)
print("start")

while(1):
    time.sleep(0.05)
    value = i2c.readfrom(0x24, 1) # Read a one byte value from I2C device with address 0x24
                                                # as defined in the Arduino code

    if value == b'a':
        close_hand()
        print("hand closed")

    if value == b'b':
        open_hand()
        print("Hand opened")



