/*
  Benoît Langeraert

  Code for the Maix Bit shield that connects to the Maix Bit through BLE, 
  this code works as peripheral in the BLE-communication.
  This code will also send 2 values based on the EMG-data that was measured.

  This code is based on Arduino example code is in the public domain.
*/

#include <ArduinoBLE.h>
#include <Wire.h> // Library for I2C communcation to communicate with the Maix Bit through I2C

BLEService ledService("19b10000-e8f2-537e-4f6c-d104768a1214"); // Bluetooth® Low Energy LED Service

// Custom 128-bit UUID, read and writable by central
BLEByteCharacteristic switchCharacteristic("19b10000-e8f2-537e-4f6c-d104768a1214", BLERead | BLEWrite);

void setup() {
  Serial.begin(9600);

  // begin initialization
  if (!BLE.begin()) {
    Serial.println("starting Bluetooth® Low Energy module failed!");
    while (1);
  }

  // set advertised local name and service UUID:
  BLE.setLocalName("Maix Bit shield");
  BLE.setAdvertisedService(ledService);

  // add the characteristic to the service
  ledService.addCharacteristic(switchCharacteristic);

  // add service
  BLE.addService(ledService);

  // set the initial value for the characeristic:
  switchCharacteristic.writeValue(0);

  // start advertising
  BLE.advertise();

  Serial.println("BLE LED Peripheral");
}

void loop() {
  // listen BLE peripherals to connect:
  BLEDevice central = BLE.central();

  // if a central is connected to peripheral:
  if (central) {
    Serial.print("Connected to central: ");
    // print the central's MAC address:
    Serial.println(central.address());
    
    Wire.begin(0x24); // A I2C communication will be set up once a connection 
                      // was established with the central (the Arduino Nano 33 BLE that measured BLE-data).
                      // 0x24 is the communication address for I2C. The Maix Bit will have the same address. 

    // while the central is still connected to peripheral:
    while (central.connected()) {

      if (switchCharacteristic.written()) {
        if (switchCharacteristic.value()) { // any value other than 0
          Serial.println("hand open");
          Wire.write('a'); // Send the value 'a' through I2C to maix bit to open hand.
          delay(50);
        } else {                          
          Serial.println("hand closed");
          Wire.write('b'); // Send the value 'b' through I2C to maix bit to open hand.
          delay(50);
        }
      }
    }
    // when the central disconnects, print it out:
    Serial.print(F("Disconnected from central: "));
    Serial.println(central.address());
  }
}
